@@ -1,6 +1,6 @@
 benchB3 <- function(method, prior=rep(1/4, 4), sv="4", scale=FALSE, ...)
 {
-data("B3", package = "klaR")
+data("B3", package = "klaR", envir = environment())
 B3 <- get("B3")
 complete <- FALSE
 y <- B3$PHASEN
