@@ -1,7 +1,7 @@
 ###############
 # preliminaries
-library(klaR)
-library(MASS)
+library("klaR")
+library("MASS")
 data(B3)
 postscript("testklaR.ps")
 
@@ -41,7 +41,7 @@ pB3 <- pB3$posterior
 
 # stepclass
 set.seed(123)
-print(SC <- stepclass(PHASEN ~ ., data = B3, method = "lda", criterion = "AS"))
+print(SC <- stepclass(PHASEN ~ ., data = B3, method = "lda", criterion = "AS", output=FALSE))
 print(lda(SC$formula, data = B3))
 
 #########
@@ -62,7 +62,7 @@ ucpm(pbB3$member, B3$PHASEN)
 # greedy.wilks
 data(B3)
 gw_obj <- greedy.wilks(PHASEN ~ ., data = B3, niveau = 0.1)
-print(gw_obj)
+print(gw_obj, digits=4)
 print(lda(gw_obj$formula, data = B3))
 gw_obj2 <- greedy.wilks(B3[,-1], B3$PHASEN, niveau = 0.1)
 identical(all.equal(gw_obj$results, gw_obj2$results), TRUE)
